MethodChannelIosStorekit2 class

Inheritance

Constructors

MethodChannelIosStorekit2()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionUpdates Stream<SK2Entitlement>
no setteroverride

Methods

getEntitlements() Future<List<SK2Entitlement>>
override
getProducts(Set<String> identifiers) Future<List<SK2Product>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purchase(String productId) Future<SK2PurchaseResult>
override
restorePurchases() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited