SK2IntroOfferInfo class

Constructors

SK2IntroOfferInfo({required SK2OfferType offerType, required SK2Period period, required double price, required String currencyCode})
const
SK2IntroOfferInfo.fromMap(Map<String, dynamic> map)
factory

Properties

currencyCode String
final
hashCode int
The hash code for this object.
no setterinherited
isTrial bool
no setter
offerType SK2OfferType
final
period SK2Period
final
periodDays int
no setter
price double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited