SK2Period class

Constructors

SK2Period({required int value, required SK2PeriodUnit unit})
const
SK2Period.fromMap(Map<String, dynamic> map)
factory

Properties

approximateDays int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unit SK2PeriodUnit
final
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited