IosStorekit2Platform class abstract
- Inheritance
-
- Object
- PlatformInterface
- IosStorekit2Platform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transactionUpdates
→ Stream<
SK2Entitlement> -
no setter
Methods
-
getEntitlements(
) → Future< List< SK2Entitlement> > -
getProducts(
Set< String> identifiers) → Future<List< SK2Product> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
purchase(
String productId) → Future< SK2PurchaseResult> -
restorePurchases(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ IosStorekit2Platform
-
getter/setter pair