SK2Entitlement class

Constructors

SK2Entitlement({required String productId, required bool isActive, SK2ProductType? productType, String? transactionId, String? originalTransactionId, DateTime? purchaseDate, DateTime? expirationDate, DateTime? revocationDate, SK2OwnershipType? ownershipType, bool isIntroOffer = false, SK2OfferType? introOfferType, bool willAutoRenew = false})
const
SK2Entitlement.fromMap(Map<String, dynamic> map)
factory

Properties

expirationDate DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
introOfferType SK2OfferType?
final
isActive bool
final
isIntroOffer bool
final
isTrial bool
no setter
originalTransactionId String?
final
ownershipType SK2OwnershipType?
final
productId String
final
productType SK2ProductType?
final
purchaseDate DateTime?
final
revocationDate DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionId String?
final
willAutoRenew bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited