SK2Product class
Constructors
- SK2Product({required String id, required String displayName, required String description, required SK2ProductType type, required double price, required String currencyCode, SK2SubscriptionInfo? subscription})
-
const
-
SK2Product.fromMap(Map<
String, dynamic> map) -
factory
Properties
- currencyCode → String
-
final
- description → String
-
final
- displayName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- price → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscription → SK2SubscriptionInfo?
-
final
- type → SK2ProductType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited