SK2SubscriptionInfo class
Constructors
- SK2SubscriptionInfo({required SK2Period period, required bool isAutoRenewable, required SK2EligibilityStatus introOfferEligibility, SK2IntroOfferInfo? introOffer})
-
const
-
SK2SubscriptionInfo.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- introOffer → SK2IntroOfferInfo?
-
final
- introOfferEligibility → SK2EligibilityStatus
-
final
- isAutoRenewable → bool
-
final
- isTrialEligible → bool?
-
no setter
- period → SK2Period
-
final
- periodDays → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trial → SK2IntroOfferInfo?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited